#!/usr/bin/python
# -*- coding: utf-8 -*-

__author__ = "Timo Stollenwerk (timo@zmag.de)"
__license__ = "GNU General Public License (GPL)"
__revision__ = "$Rev: 178 $"
__date__ = "$Date: 2008-03-01 23:21:48 +0100 (Sat, 01 Mar 2008) $"
__URL__ = "$URL: http://svn.zmag.de/svn/python/docbook2sla/trunk/docbook2sla/logger.py $"

import logging

LOG = logging.getLogger()
